@@ -18,12 +18,15 @@ def print_egginfo_removal_instructions(output_dir, vars, extra_reverts=None):
     """Print egg-info removal instructions."""
     if extra_reverts is None:
         extra_reverts = []
+    using_svn = os.path.exists(os.path.join(output_dir, '.svn'))
+
     egginfo_dirname = '%(package)s.egg-info' % vars
     print
     print "Manual task that you need to do:"
     print "cd %s" % output_dir
-    print "svn revert %s" % egginfo_dirname
-    for extra_revert in extra_reverts:
-        print "svn revert %s" % extra_revert
+    if using_svn:
+        print "svn revert %s" % egginfo_dirname
+        for extra_revert in extra_reverts:
+            print "svn revert %s" % extra_revert
     print "rm -rf %s" % egginfo_dirname
     print
